Jump to content

OpenCL: Setup & Hello World: Revision history

Diff selection: Mark the radio buttons of the revisions to compare and hit enter or the button at the bottom.
Legend: (cur) = difference with latest revision, (prev) = difference with preceding revision, m = minor edit.

2 January 2026

  • curprev 08:2908:29, 2 January 2026 SanzSkuy talk contribs 3,275 bytes −8 No edit summary
  • curprev 08:2508:25, 2 January 2026 SanzSkuy talk contribs 3,283 bytes +1 No edit summary
  • curprev 08:2508:25, 2 January 2026 SanzSkuy talk contribs 3,282 bytes +3,282 Created page with "Install OpenCL (untuk Nvidia) <syntaxhighligh lang=bash> sudo pacman -S opencl-headers ocl-icd opencl-nvidia </syntaxhighlight> main.cpp <syntaxhighlight lang=cpp> #include <CL/cl.h> #include <iostream> #include <vector> const char* kernelSource = R"( __kernel void vector_add(__global const float* a, __global const float* b, __global float* c) { int gid = get_global_id(0); c[gid] = a[gid] + b[gid]; } )"; int mai..."